@@ -23,23 +23,30 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-Wsign-compare',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe -std=c11 '
-                            '-Wextra -Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic '
+                            '-Werror=odr -Werror=lto-type-mismatch '
+                            '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                            '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                            '-std=c11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
- 'CONFIGURE_LDFLAGS_NOLTO': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
+                             '-Wl,-z,pack-relative-relocs -Werror=odr '
+                             '-Werror=lto-type-mismatch '
+                             '-Werror=strict-aliasing -flto -flto '
+                             '-fuse-linker-plugin -ffat-lto-objects -g',
+ 'CONFIGURE_LDFLAGS_NOLTO': '-fno-lto',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
@@ -56,13 +63,12 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--disable-optimizations' "
-                "'--with-readline=readline' '--without-valgrind' "
+                "'--with-assertions' '--disable-optimizations' "
+                "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' "
-                "'PKG_CONFIG_PATH=/opt/cuda/pkgconfig' 'CFLAGS=' 'LDFLAGS=' "
-                "'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
+                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
@@ -139,7 +145,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ATANH': 1,
  'HAVE_BIND': 1,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
@@ -182,7 +188,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CURSES_TYPEAHEAD': 1,
  'HAVE_CURSES_USE_ENV': 1,
  'HAVE_CURSES_WCHGAT': 1,
- 'HAVE_DB_H': 0,
+ 'HAVE_DB_H': 1,
  'HAVE_DECL_RTLD_DEEPBIND': 1,
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
@@ -322,7 +328,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
  'HAVE_LIBB2': 1,
- 'HAVE_LIBDB': 0,
+ 'HAVE_LIBDB': 1,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
  'HAVE_LIBGDBM_COMPAT': 1,
@@ -613,15 +619,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
-            '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
-                 '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
+                 '-m 644',
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.3ygegrof/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
@@ -637,10 +642,12 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 -mtune=generic '
-                    '-pipe -std=c11 -Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 -mtune=generic '
+                    '-Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
+                    '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
@@ -649,10 +656,12 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 -Wsign-compare '
-                    '-DNDEBUG -O2 -march=x86-64 -mtune=generic -pipe -std=c11 '
-                    '-Wextra -Wno-unused-parameter '
-                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                    '-Werror=implicit-function-declaration '
+                    '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
+                    '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                    '-ffat-lto-objects -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
@@ -907,7 +916,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '-DNDEBUG',
+ 'OPT': '',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -943,43 +952,59 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 '
-                             '-mtune=generic -pipe -std=c11 -Wextra '
-                             '-Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 '
+                             '-mtune=generic -Werror=odr '
+                             '-Werror=lto-type-mismatch '
+                             '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                             '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                             '-std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -march=x86-64 -mtune=generic -pipe -std=c11 -Wextra '
+ 'PY_CFLAGS': '-Wsign-compare',
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
+                     '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                     '-ffat-lto-objects -flto -fuse-linker-plugin '
+                     '-ffat-lto-objects -g -std=c11 -Wextra '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 -mtune=generic '
-                   '-pipe -std=c11 -Wextra -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 -mtune=generic '
+                   '-Werror=odr -Werror=lto-type-mismatch '
+                   '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
+                   '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                    '-Werror=odr -Werror=lto-type-mismatch '
+                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
- 'PY_LDFLAGS_NOLTO': '',
+ 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                      '-Werror=odr -Werror=lto-type-mismatch '
+                      '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                      '-ffat-lto-objects -g',
+ 'PY_LDFLAGS_NOLTO': '-fno-lto',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -march=x86-64 '
-                        '-mtune=generic -pipe -std=c11 -Wextra '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -O2 -pipe -march=x86-64 -mtune=generic '
+                        '-Werror=odr -Werror=lto-type-mismatch '
+                        '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
+                        '-fuse-linker-plugin -ffat-lto-objects -g -std=c11 '
+                        '-Wextra -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
